@@ -5,7 +5,7 @@ use warnings;
 use Carp::Clan qw/^DBIx::Class/;
 use Class::C3;
 
-our $VERSION = '0.04999_10';
+our $VERSION = '0.04999_11';
 
 =head1 NAME
 
@@ -72,7 +72,12 @@ L<DBIx::Class::Schema::Loader>, L<DBIx::Class::Schema::Loader::Base>,
 
 =head1 AUTHOR
 
-Rafael Kitover <rkitover@cpan.org>
+See L<DBIx::Class::Schema::Loader/CONTRIBUTORS>.
+
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.
 
 =cut
 
